using RimWorld;
using UnityEngine;
using Verse;

namespace SladkiTweaks
{
    public class Settings : ModSettings
    {
        // Economy
        public bool ammoIsCurrency = true;
        // Recipes
        public bool changeRecipes = true;
        public bool chemfuelRequired = true;
        public float recipeProductsMult = 0.04f;
        // Traders stock
        public bool changeTradersStock = true;
        public bool caravansHaveExplosives = true;
        // DEBUG
        public bool debugMode = false;

        public override void ExposeData()
        {
            base.ExposeData();
            // Economy
            Scribe_Values.Look<bool>(ref ammoIsCurrency, "ammoIsCurrency", true);
            // Recipes
            Scribe_Values.Look<bool>(ref changeRecipes, "changeRecipes", true);
            Scribe_Values.Look<bool>(ref chemfuelRequired, "chemfuelRequired", true);
            Scribe_Values.Look<float>(ref recipeProductsMult, "recipeProductsMult", 0.04f);
            // Traders stock
            Scribe_Values.Look<bool>(ref changeTradersStock, "changeTradersStock", true);
            Scribe_Values.Look<bool>(ref caravansHaveExplosives, "caravansHaveExplosives", true);
            // DEBUG
            Scribe_Values.Look<bool>(ref debugMode, "debugMode", false);
        }

        public void DoWindowContents(Rect canvas)
        {
            Listing_Standard list = new Listing_Standard();
            list.ColumnWidth = canvas.width;
            list.Begin(canvas);
            // Economy
            Category(list, "Economy");
            list.CheckboxLabeled(
                    "Ammo is a currency",
                    ref ammoIsCurrency,
                    "When trading, ammo has no minimal price.\nMaximum bargain percent is 15% (instead of 40%)."
            );
            list.Gap(24f);
            // Recipes
            Category(list, "Recipes");
            list.CheckboxLabeled(
                    "Change recipes*",
                    ref changeRecipes,
                    "Change ammo recipes.\nRecipe product quantity decreased, required ingredients also adjusted."
            );
            if(changeRecipes)
            {
                Text.Font = GameFont.Tiny;
                list.Label("Recipe output decreased: " + Mathf.RoundToInt(1 / recipeProductsMult) + "x times*");
                list.verticalSpacing = 0f;
                recipeProductsMult = 1 / list.Slider(1 / recipeProductsMult, 2f, 25f);
                list.verticalSpacing = 2f;
                Text.Font = GameFont.Small;
                list.CheckboxLabeled(
                        "Chemfuel required*",
                        ref chemfuelRequired,
                        "Some of the ammunition require chemfuel as propellant for crafting."
                );
            }
            Text.Font = GameFont.Tiny;
            list.Label(" * Restart required in order to apply changes");
            Text.Font = GameFont.Small;
            list.Gap(24f);
            // Traders stock
            Category(list, "Traders stock");
            list.CheckboxLabeled(
                    "Change traders ammunition stock",
                    ref changeTradersStock,
                    "Traders have significantly less ammo for sale.\nAmmo stock depends on relations with trader faction and " +
                    "on commonality of the specified ammo."
            );
            list.CheckboxLabeled(
                    "Caravans don't sell explosives",
                    ref caravansHaveExplosives,
                    "Arriving caravans and orbital traders don't sell shells and other things that are being used as ammo and explode."
            );
            // DEBUG
            if(Prefs.DevMode || debugMode)
            {
                list.CheckboxLabeled(
                    "DEBUG MODE",
                    ref debugMode,
                    "Debug mode. Switch on if you need it."
                );
            }
            list.End();
        }

        private void Category(Listing_Standard list, string title)
        {
            Text.Font = GameFont.Medium;
            list.Label(title);
            Text.Font = GameFont.Small;
            list.GapLine(2f);
        }
    }
}